@@ -1,6 +1,8 @@
 from easyfed.cortex.main import server,client
 import os
 import argparse
+import subprocess
+client_dir=subprocess.getoutput("pwd")
 bdir=os.path.dirname(os.path.abspath(__file__))
 def fedserver(port=16668):
     parser = argparse.ArgumentParser()
