@@ -1,16 +1,31 @@
 import torch
 import copy
 import os
+import crypten
+import torch
+import time
+
+crypten.init()
+import collections
 from FModel.models import Clients
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 savefile=os.path.join(BASE_DIR, 'static', 'modelfile','clients.tsv')
 #
+alive_client={}
+def setsession(key):
+    s=time.time()
+    alive_client[key]=s
+def getsession(key):
+    s=time.time()
+    if key in alive_client:
+        if (s-alive_client[key])>300:
+            del alive_client[key]
+    return alive_client.get(key,-1)
 def getClients():
     clients=Clients.objects.all()
     print('clients',len(clients))
     clientsList=[]
     for cl in clients:
-        print(cl.Key)  
         item={}
         item['id']=cl.CID
         item['name']=cl.CName
@@ -30,7 +45,6 @@ def setClientStatus(key,status):
             result=1
     return result
 def getClientId(cname,key=None):
-    print('key00000000',key)
     context={}
     context['result']=0
     if not key.strip():
@@ -59,7 +73,21 @@ def average_weights(w):
         w_avg[key] = torch.div(w_avg[key], len(w))
     return w_avg
 
-def check_fed_model(save_dir,keys,test_acc=None,test_loss=None,EpochCount=None):
+def average_weights_enc(w):
+    """
+    Returns the average of the weights.
+    """
+    new_w = collections.OrderedDict()
+    w_avg = copy.deepcopy(w[0])
+    for key in w_avg.keys():
+        for i in range(1, len(w)):
+            w_avg[key]=w_avg[key].cpu()
+            w_avg[key] +=w[i][key].cpu()
+        # w_avg[key] = torch.div(w_avg[key].get_plain_text(), len(w))
+        new_w[key.replace('.data','')]=torch.div(w_avg[key].get_plain_text(), len(w))
+    return new_w
+
+def check_fed_model(save_dir,keys,type,test_acc=None,test_loss=None,EpochCount=None):
     print('check_fed_model',save_dir,keys)
     # addtasklog(save_dir,clientnumber,taskname,'test_acc',test_acc,'test_loss',test_loss,_clientid)
     result=1
@@ -72,7 +100,10 @@ def check_fed_model(save_dir,keys,test_acc=None,test_loss=None,EpochCount=None):
     except Exception as es:
         print(es)
     if result==3:
-        avg_model=average_weights(cmodels)
+        if type=='plain':
+            avg_model=average_weights(cmodels)
+        else:
+            avg_model=average_weights_enc(cmodels)
         if avg_model:
             for key in keys:
                 try:
